pub struct DdcCiData { /* private fields */ }Expand description
An i2c request has been made to the DDC/CI address (0x37).
Implementations
sourceimpl DdcCiData
impl DdcCiData
DDC/CI data notification
All documentation of DdciData is my best guess based on reading the source and googling. You may find reading about general protocol i2c that DDC/CI data is transmitted over useful.
sourcepub fn flag_read_request(&self) -> bool
pub fn flag_read_request(&self) -> bool
Indicates driver intends to read data from the virtual display
sourcepub fn flag_write_request(&self) -> bool
pub fn flag_write_request(&self) -> bool
Indicates driver intends to write data to the virtual display
pub fn buffer(&self) -> &[u8] ⓘ